@@ -8,18 +8,19 @@ given by Dropbox application registration process.
 By default account id and token expiration time are stored in extra_data
 field, check OAuthBackend class for details on how to extend it.
 """
-from django.utils import simplejson
-
-from social.backends.oauth import ConsumerBasedOAuth
+from social.backends.oauth import BaseOAuth1
 
 
-class DropboxOAuth(ConsumerBasedOAuth):
+class DropboxOAuth(BaseOAuth1):
     """Dropbox OAuth authentication backend"""
     name = 'dropbox'
     ID_KEY = 'uid'
     AUTHORIZATION_URL = 'https://www.dropbox.com/1/oauth/authorize'
     REQUEST_TOKEN_URL = 'https://api.dropbox.com/1/oauth/request_token'
+    REQUEST_TOKEN_METHOD = 'POST'
     ACCESS_TOKEN_URL = 'https://api.dropbox.com/1/oauth/access_token'
+    ACCESS_TOKEN_METHOD = 'POST'
+    REDIRECT_URI_PARAMETER_NAME = 'oauth_callback'
     EXTRA_DATA = [
         ('id', 'id'),
         ('expires', 'expires')
@@ -33,10 +34,5 @@ class DropboxOAuth(ConsumerBasedOAuth):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        url = 'https://api.dropbox.com/1/account/info'
-        request = self.oauth_request(access_token, url)
-        response = self.fetch_response(request)
-        try:
-            return simplejson.loads(response)
-        except ValueError:
-            return None
+        return self.get_json('https://api.dropbox.com/1/account/info',
+                             auth=self.oauth_auth(access_token))
