@@ -25,6 +25,7 @@ class SQLAlchemyMixin(object):
 
     @classmethod
     def _save_instance(cls, instance):
+        cls._session().add(instance)
         cls._session().commit()
         return instance
 
@@ -63,6 +64,7 @@ class SQLAlchemyUserMixin(SQLAlchemyMixin, UserMixin):
             else:
                 qs = qs.filter_by(provider=name)
             qs.delete()
+            cls._session().commit()
         else:
             raise NotAllowedToDisconnect()
 
@@ -144,7 +146,7 @@ class SQLAlchemyAssociationMixin(SQLAlchemyMixin, AssociationMixin):
 
     @classmethod
     def remove(cls, ids_to_delete):
-        cls._query().filter(cls.id.in_(ids_to_delete)).delete()
+        cls._query().filter(cls.id.in_(ids_to_delete)).delete(synchronize_session='fetch')
 
 
 class BaseSQLAlchemyStorage(BaseStorage):
