@@ -93,6 +93,9 @@ class BaseStrategy(object):
         self.session_set(name, value)
         return self.session_get(name)
 
+    def openid_session_dict(self, name):
+        return self.session_setdefault(name, {})
+
     def to_session_value(self, val):
         return val
 
@@ -146,6 +149,16 @@ class BaseStrategy(object):
     def is_integrity_error(self, exception):
         return self.storage.is_integrity_error(exception)
 
+    def absolute_uri(self, path=None):
+        uri = self.build_absolute_uri(path)
+        if self.setting('ON_HTTPS'):
+            uri = uri.replace('http://', 'https://')
+        return uri
+
+    def get_language(self):
+        """Return current language"""
+        return ''
+
     # Implement the following methods on strategies sub-classes
 
     def redirect(self, url):
